"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfig = void 0;
const webpack_bundle_analyzer_1 = require("webpack-bundle-analyzer");
const terser_webpack_plugin_1 = __importDefault(require("terser-webpack-plugin"));
const getEntry_js_1 = require("./getEntry.js");
const getExternals_1 = require("./getExternals");
const path_1 = __importDefault(require("path"));
const webpack_1 = __importDefault(require("webpack"));
function getSingleConfig(params, min) {
    const { additionalExternals, banner, bundle, dir, entry, minBanner, version } = params;
    return {
        entry: (0, getEntry_js_1.getEntry)({ ...entry, min }),
        mode: min ? "production" : "development",
        output: {
            path: path_1.default.resolve(dir, "dist"),
            filename: "[name].js",
            library: {
                type: "umd2",
            },
            globalObject: "this",
            chunkFilename: min ? "[name].min.js" : "[name].js",
        },
        resolve: {
            extensions: [".cjs", ".mjs", ".js", ".json"],
        },
        externals: (0, getExternals_1.getExternals)({ bundle, additionalExternals }),
        module: {
            rules: [
                {
                    test: /\.js$/,
                    exclude: /node_modules/,
                    loader: "babel-loader",
                },
            ],
        },
        plugins: [
            new webpack_1.default.DefinePlugin({
                __VERSION__: JSON.stringify(version),
            }),
            new webpack_1.default.BannerPlugin({
                banner,
                exclude: /\.min\.js$/,
            }),
            new webpack_1.default.BannerPlugin({
                banner: minBanner,
                include: /\.min\.js$/,
            }),
            new webpack_1.default.ProgressPlugin(),
            new webpack_bundle_analyzer_1.BundleAnalyzerPlugin({
                openAnalyzer: false,
                analyzerMode: "static",
                excludeAssets: /\.min\.js$/,
                reportFilename: "report.html",
            }),
        ],
        optimization: {
            minimize: true,
            minimizer: [
                new terser_webpack_plugin_1.default({
                    include: /\.min\.js$/,
                    parallel: true,
                    terserOptions: {
                        ecma: 2019,
                        module: true,
                    },
                }),
            ],
        },
        performance: {
            hints: false,
        },
    };
}
const getConfig = (params) => {
    return [getSingleConfig(params, false), getSingleConfig(params, true)];
};
exports.getConfig = getConfig;
